@@ -5,11 +5,11 @@
 import numpy as np
 import warnings
 import networkx as nx
-from MMDGraph.MONK import MMD_MONK
+from GTST.MONK import MMD_MONK
 import tqdm
 
-from MMDGraph.kernels import RandomWalk, WWL, GNTK, DeepKernel
-import MMDGraph.glasso as glasso
+from GTST.kernels import RandomWalk, WWL, GNTK, DeepKernel
+import GTST.glasso as glasso
 
 # Biased empirical maximum mean discrepancy
 def MMD_b(K: np.array, n1: int, n2: int):
@@ -293,6 +293,13 @@ class MMD():
 
 
     def get_mmd_func_pair(self, estimator, Q = None):
+        """
+        estimator: str,
+            which estimator to use
+        Q: int,
+            Number of partitions for MONK
+        
+        """
 
         if estimator == 'MMD_u':
             ret = (MMD_u, {'MMD_u':dict(n1=self.n1, n2=self.n2)})
@@ -311,8 +318,11 @@ class MMD():
         
     def estimate_graphs(self,X1, X2, window_size:int,alpha:float, beta:float, nonparanormal:bool = False, scale:bool = False, set_attributes = None, set_labels = None ):
         """
-        X1,X2: araray like,
-            real data for sample 1 and 2
+        Estimate two graph samples from two data matrices.
+
+
+        X1,X2: array like,
+            real data for samples 1 and 2
         window_size: int,
             number of data points to estimate each graph
         alpha: list, float,
@@ -323,11 +333,12 @@ class MMD():
             Should data be nonparanormally transformed
         scale:bool,
             Should data be scaled
-        get_attribute: function or None,
+        set_attributes: function or None,
             Set attribute of nodes. If a function should take numpy array  (which will be a submatrix of X1,X2) as input and output attributes for each node/parameter, used as an attribute for a graph kernel.
-        set_labels: function, str or None:
+        set_labels: function, str, dict or None:
             Set labels of nods: If a function should take networkx graph as input and output labels for each node/parameter.  Should return a dict {node_i:label,..}
-            If string should be degree and the labels will be labeled as degree
+            If string = 'degree' then nodes will be labelled with degree
+            If dict, then should be: dict['1'] = dictionary with label for each node in sample 1 ({node:label}),dict['2'] = dictionary with label for each node in sample 2 ({node:label})
             If None no labelling
 
         """
@@ -337,7 +348,7 @@ class MMD():
         self.nonparanormal = nonparanormal
         self.scale = scale
         
-        # store if attributes, labels are being set
+        # If attributes or labels are being set the we give them this name
         if set_attributes is not None:
             self.node_attr = 'attr'
         
@@ -359,7 +370,7 @@ class MMD():
         self.G1 = []
         self.G2 = []
 
-         # Estimate precision 1
+        # Estimate precision 1
         for i in range(window_size,X1.shape[0]+1,window_size):
             # Extract data points used to estimate a precision matrix
             tmp_X1= X1[(i-window_size):(i)].copy()
